==> jc-1.4.0.tar.gz: javax/naming/directory/BasicAttribute__24BasicAttributeEnumeration.h <==
// class javax.naming.directory.BasicAttribute$BasicAttributeEnumeration

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2e2cf5c92cee0dba javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration_H_
#define _JC_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_javax_naming_directory_BasicAttribute$object;

// Typedefs
typedef struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$sub_refs	_jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$sub_refs;
typedef struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$sub_nonrefs	_jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$sub_nonrefs;
typedef struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$refs	_jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$refs;
typedef struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$nonrefs	_jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$nonrefs;
typedef struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$object	_jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$object;

typedef const struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$vmethods	_jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$vmethods;
typedef const struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$vtable	_jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$vtable;
typedef const struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$vtype	_jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$vtype;

// Constructors
extern void _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$method$_init$d3e2d7b37ffc3d1e(_jc_env *, struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$object *, struct _jc_javax_naming_directory_BasicAttribute$object *);

// Virtual methods
extern void _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$object *);
extern jboolean _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$method$hasMore$1fc147586a714e39(_jc_env *, struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$object *);
extern jboolean _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$method$hasMoreElements$95fbe58f36adadb0(_jc_env *, struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$object *);
extern struct _jc_java_lang_Object$object *_jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$object *);
extern struct _jc_java_lang_Object$object *_jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$method$nextElement$9b7c3789fa3ba818(_jc_env *, struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$object *);
extern void _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$method_info$hasMore$1fc147586a714e39;
extern _jc_method _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$method_info$hasMoreElements$95fbe58f36adadb0;
extern _jc_method _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$method_info$nextElement$9b7c3789fa3ba818;
extern _jc_method _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$object *);
	jboolean	(*hasMore$1fc147586a714e39)(_jc_env *, struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$object *);
	jboolean	(*hasMoreElements$95fbe58f36adadb0)(_jc_env *, struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$object *);
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$object *);
	struct _jc_java_lang_Object$object	*(*nextElement$9b7c3789fa3ba818)(_jc_env *, struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$object *);
};

// Vtable
struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$vmethods	javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration;
};

// Vtype
struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$vtype {
	_jc_type			type;
	_jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$sub_refs {
	struct _jc_javax_naming_directory_BasicAttribute$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$refs {
    _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$sub_refs	javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$sub_nonrefs {
	jint	where;
};

// Non-reference instance fields (object)
struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$sub_nonrefs	javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration;
};

// Object instance structure
struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$object {
	_jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$vtype	*vtype;
	_jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$vtype _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$class_object;

#endif	/* _JC_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration_H_ */

==> jc-1.4.6.tar.gz: javax/naming/directory/BasicAttribute__24BasicAttributeEnumeration.h <==
// class javax.naming.directory.BasicAttribute$BasicAttributeEnumeration

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2e2cf5c92cee0dba javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration_H_
#define _JC_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_javax_naming_directory_BasicAttribute$object;

// Typedefs
typedef struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$sub_refs	_jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$sub_refs;
typedef struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$sub_nonrefs	_jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$sub_nonrefs;
typedef struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$refs	_jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$refs;
typedef struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$nonrefs	_jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$nonrefs;
typedef struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$object	_jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$object;

typedef const struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$vmethods	_jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$vmethods;
typedef const struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$vtable	_jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$vtable;
typedef const struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$vtype	_jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$vtype;

// Constructors
extern void _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$method$_init$d3e2d7b37ffc3d1e(_jc_env *, struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$object *, struct _jc_javax_naming_directory_BasicAttribute$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$method$hasMore$1fc147586a714e39(_jc_env *, struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$method$hasMoreElements$95fbe58f36adadb0(_jc_env *, struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$method$nextElement$9b7c3789fa3ba818(_jc_env *, struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$object *) _JC_JCNI_ATTR;
extern void _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$method_info$hasMore$1fc147586a714e39;
extern _jc_method _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$method_info$hasMoreElements$95fbe58f36adadb0;
extern _jc_method _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$method_info$nextElement$9b7c3789fa3ba818;
extern _jc_method _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$object *) _JC_JCNI_ATTR;
	jboolean	(*hasMore$1fc147586a714e39)(_jc_env *, struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$object *) _JC_JCNI_ATTR;
	jboolean	(*hasMoreElements$95fbe58f36adadb0)(_jc_env *, struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*nextElement$9b7c3789fa3ba818)(_jc_env *, struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$vmethods	javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration;
};

// Vtype
struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$vtype {
	_jc_type			type;
	_jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$sub_refs {
	struct _jc_javax_naming_directory_BasicAttribute$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$refs {
    _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$sub_refs	javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$sub_nonrefs {
	jint	where;
};

// Non-reference instance fields (object)
struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$sub_nonrefs	javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration;
};

// Object instance structure
struct _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$object {
	_jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$vtype	*vtype;
	_jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$vtype _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration$class_object;

#endif	/* _JC_javax_naming_directory_BasicAttribute__24BasicAttributeEnumeration_H_ */
